@@ -2,7 +2,7 @@ context("Thin")
 
 test_that("Thin ouputs are correct", {
     x <- make_epicontacts(ebola_sim$linelist, ebola_sim$contacts,
-                           id = "case.id", to = "case.id", from = "infector",
+                           id = "case_id", to = "case_id", from = "infector",
                            directed = TRUE)
 
     y <- x[j = "916d0a", contacts = "from"]
@@ -11,7 +11,7 @@ test_that("Thin ouputs are correct", {
     ## check expected errors
     expect_error(thin(1), "x is not an epicontacts object")
     msg <- paste0("Wrong values for 'what'; accepted values are:\n",
-                      "'linelist', 'contact', 1, 2")       
+                      "'linelist', 'contact', 1, 2")
     expect_error(thin(x, 3), msg)
     expect_error(thin(x, "foo"), msg)
 
@@ -26,5 +26,5 @@ test_that("Thin ouputs are correct", {
     expect_true(all(get_id(thin(x)) %in% get_id(x, "contacts")))
     expect_true(all(get_id(thin(x,2), "contacts") %in%
                     get_id(x)))
-    
+
 })
